@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWIntervalReference.h,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: FWIntervalReference.h,v 1.3 2006/09/10 22:40:36 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@ class FWIntervalReference : public FWReference
     DECLARE_FWOBJECT_SUBTYPE(FWIntervalReference);
 
     FWIntervalReference();
-    FWIntervalReference(const FWObject *root);
+    FWIntervalReference(const FWObject *root,bool prepopulate);
 
     void setPointer(Interval *o);
     void setPointer(IntervalGroup *o);
